const $={reset:[0,0],bold:[1,22],dim:[2,22],italic:[3,23],underline:[4,24],overline:[53,55],inverse:[7,27],hidden:[8,28],strikethrough:[9,29],black:[30,39],red:[31,39],green:[32,39],yellow:[33,39],blue:[34,39],magenta:[35,39],cyan:[36,39],white:[37,39],blackBright:[90,39],redBright:[91,39],greenBright:[92,39],yellowBright:[93,39],blueBright:[94,39],magentaBright:[95,39],cyanBright:[96,39],whiteBright:[97,39],bgBlack:[40,49],bgRed:[41,49],bgGreen:[42,49],bgYellow:[43,49],bgBlue:[44,49],bgMagenta:[45,49],bgCyan:[46,49],bgWhite:[47,49],bgBlackBright:[100,49],bgRedBright:[101,49],bgGreenBright:[102,49],bgYellowBright:[103,49],bgBlueBright:[104,49],bgMagentaBright:[105,49],bgCyanBright:[106,49],bgWhiteBright:[107,49]};function K(r,e,t,n=!1){const i=String(e),o=(a,h)=>`\x1B[${h[0]}m${a}\x1B[${h[1]}m`,s=(a,h)=>h!=null&&typeof h=="string"?o(a,$[h]):h!=null&&Array.isArray(h)?h.reduce((l,c)=>s(l,c),a):h!=null&&h[a.trim()]!=null?s(a,h[a.trim()]):h!=null&&h["*"]!=null?s(a,h["*"]):a,f=null;return i.replace(/{{(.+?)}}/g,(a,h)=>{var c;const l=t[h]!=null?String(t[h]):n?"":a;return r.stylePrettyLogs?s(l,((c=r==null?void 0:r.prettyLogStyles)==null?void 0:c[h])??f)+o("",$.reset):l})}function u(r,e=2,t=0){return r!=null&&isNaN(r)?"":(r=r!=null?r+t:r,e===2?r==null?"--":r<10?"0"+r:r.toString():r==null?"---":r<10?"00"+r:r<100?"0"+r:r.toString())}function re(r){return{href:r.href,protocol:r.protocol,username:r.username,password:r.password,host:r.host,hostname:r.hostname,port:r.port,pathname:r.pathname,search:r.search,searchParams:[...r.searchParams].map(([e,t])=>({key:e,value:t})),hash:r.hash,origin:r.origin}}function g(r){const e=new Set;return JSON.stringify(r,(t,n)=>{if(typeof n=="object"&&n!==null){if(e.has(n))return"[Circular]";e.add(n)}return typeof n=="bigint"?`${n}`:n})}function p(r,e){const t={seen:[],stylize:Y};return e!=null&&X(t,e),d(t.showHidden)&&(t.showHidden=!1),d(t.depth)&&(t.depth=2),d(t.colors)&&(t.colors=!0),d(t.customInspect)&&(t.customInspect=!0),t.colors&&(t.stylize=ne),z(t,r,t.depth)}p.colors=$;p.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"};function te(r){return typeof r=="boolean"}function d(r){return r===void 0}function Y(r){return r}function ne(r,e){var n,i,o,s;const t=p.styles[e];return t!=null&&((i=(n=p==null?void 0:p.colors)==null?void 0:n[t])==null?void 0:i[0])!=null&&((s=(o=p==null?void 0:p.colors)==null?void 0:o[t])==null?void 0:s[1])!=null?"\x1B["+p.colors[t][0]+"m"+r+"\x1B["+p.colors[t][1]+"m":r}function R(r){return typeof r=="function"}function Z(r){return typeof r=="string"}function ie(r){return typeof r=="number"}function q(r){return r===null}function Q(r,e){return Object.prototype.hasOwnProperty.call(r,e)}function W(r){return _(r)&&b(r)==="[object RegExp]"}function _(r){return typeof r=="object"&&r!==null}function I(r){return _(r)&&(b(r)==="[object Error]"||r instanceof Error)}function G(r){return _(r)&&b(r)==="[object Date]"}function b(r){return Object.prototype.toString.call(r)}function oe(r){const e={};return r.forEach(t=>{e[t]=!0}),e}function se(r,e,t,n,i){const o=[];for(let s=0,f=e.length;s<f;++s)Q(e,String(s))?o.push(U(r,e,t,n,String(s),!0)):o.push("");return i.forEach(s=>{s.match(/^\d+$/)||o.push(U(r,e,t,n,s,!0))}),o}function V(r){return"["+Error.prototype.toString.call(r)+"]"}function z(r,e,t=0){if(r.customInspect&&e!=null&&R(e)&&(e==null?void 0:e.inspect)!==p&&!(e!=null&&e.constructor&&(e==null?void 0:e.constructor.prototype)===e)){if(typeof e.inspect!="function"&&e.toString!=null)return e.toString();let l=e==null?void 0:e.inspect(t,r);return Z(l)||(l=z(r,l,t)),l}const n=m(r,e);if(n)return n;let i=Object.keys(e);const o=oe(i);try{r.showHidden&&Object.getOwnPropertyNames&&(i=Object.getOwnPropertyNames(e))}catch{}if(I(e)&&(i.indexOf("message")>=0||i.indexOf("description")>=0))return V(e);if(i.length===0)if(R(r.stylize)){if(R(e)){const l=e.name?": "+e.name:"";return r.stylize("[Function"+l+"]","special")}if(W(e))return r.stylize(RegExp.prototype.toString.call(e),"regexp");if(G(e))return r.stylize(Date.prototype.toISOString.call(e),"date");if(I(e))return V(e)}else return e;let s="",f=!1,a=[`{
`,`
}`];if(Array.isArray(e)&&(f=!0,a=[`[
`,`
]`]),R(e)&&(s=" [Function"+(e.name?": "+e.name:"")+"]"),W(e)&&(s=" "+RegExp.prototype.toString.call(e)),G(e)&&(s=" "+Date.prototype.toUTCString.call(e)),I(e)&&(s=" "+V(e)),i.length===0&&(!f||e.length==0))return a[0]+s+a[1];if(t<0)return W(e)?r.stylize(RegExp.prototype.toString.call(e),"regexp"):r.stylize("[Object]","special");r.seen.push(e);let h;return f?h=se(r,e,t,o,i):h=i.map(l=>U(r,e,t,o,l,f)),r.seen.pop(),fe(h,s,a)}function U(r,e,t,n,i,o){let s,f,a={value:void 0};try{a.value=e[i]}catch{}try{Object.getOwnPropertyDescriptor&&(a=Object.getOwnPropertyDescriptor(e,i)||a)}catch{}if(a.get?a.set?f=r.stylize("[Getter/Setter]","special"):f=r.stylize("[Getter]","special"):a.set&&(f=r.stylize("[Setter]","special")),Q(n,i)||(s="["+i+"]"),f||(r.seen.indexOf(a.value)<0?(q(t)?f=z(r,a.value,void 0):f=z(r,a.value,t-1),f.indexOf(`
`)>-1&&(o?f=f.split(`
`).map(h=>"  "+h).join(`
`).substr(2):f=`
`+f.split(`
`).map(h=>"   "+h).join(`
`))):f=r.stylize("[Circular]","special")),d(s)){if(o&&i.match(/^\d+$/))return f;s=JSON.stringify(""+i),s.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(s=s.substr(1,s.length-2),s=r.stylize(s,"name")):(s=s.replace(/'/g,"\\'").replace(/\\"/g,"\\'").replace(/(^"|"$)/g,"'"),s=r.stylize(s,"string"))}return s+": "+f}function m(r,e){if(d(e))return r.stylize("undefined","undefined");if(Z(e)){const t="'"+JSON.stringify(e).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,"\\'")+"'";return r.stylize(t,"string")}if(ie(e))return r.stylize(""+e,"number");if(te(e))return r.stylize(""+e,"boolean");if(q(e))return r.stylize("null","null")}function fe(r,e,t){return t[0]+(e===""?"":e+`
`)+"  "+r.join(`,
  `)+" "+t[1]}function X(r,e){const t={...r};if(!e||!_(e))return r;const n={...e},i=Object.keys(e);let o=i.length;for(;o--;)t[i[o]]=n[i[o]];return t}function ae(r,...e){const t={seen:[],stylize:Y};r!=null&&X(t,r);const n=e[0];let i=0,o="",s="";if(typeof n=="string"){if(e.length===1)return n;let f,a=0;for(let h=0;h<n.length-1;h++)if(n.charCodeAt(h)===37){const l=n.charCodeAt(++h);if(i+1!==e.length){switch(l){case 115:{const c=e[++i];typeof c=="number"||typeof c=="bigint"?f=m(t,c):typeof c!="object"||c===null?f=String(c):f=p(c,{...r,compact:3,colors:!1,depth:0});break}case 106:f=g(e[++i]);break;case 100:{const c=e[++i];typeof c=="bigint"?f=m(t,c):typeof c=="symbol"?f="NaN":f=m(t,c);break}case 79:f=p(e[++i],r);break;case 111:f=p(e[++i],{...r,showHidden:!0,showProxy:!0,depth:4});break;case 105:{const c=e[++i];typeof c=="bigint"?f=m(t,c):typeof c=="symbol"?f="NaN":f=m(t,parseInt(f));break}case 102:{const c=e[++i];typeof c=="symbol"?f="NaN":f=m(t,parseInt(c));break}case 99:i+=1,f="";break;case 37:o+=n.slice(a,h),a=h+1;continue;default:continue}a!==h-1&&(o+=n.slice(a,h-1)),o+=f,a=h+1}else l===37&&(o+=n.slice(a,h),a=h+1)}a!==0&&(i++,s=" ",a<n.length&&(o+=n.slice(a)))}for(;i<e.length;){const f=e[i];o+=s,o+=typeof f!="string"?p(f,r):f,s=" ",i++}return o}const he={getCallerStackFrame:O,getErrorTrace:v,getMeta:pe,transportJSON:de,transportFormatted:me,isBuffer:ye,isError:M,prettyFormatLogObj:ue,prettyFormatErrorObj:ee};var H;const le={runtime:[typeof window,typeof document].includes("undefined")?"Generic":"Browser",browser:(H=globalThis==null?void 0:globalThis.navigator)==null?void 0:H.userAgent},ce=/(?:(?:file|https?|global code|[^@]+)@)?(?:file:)?((?:\/[^:/]+){2,})(?::(\d+))?(?::(\d+))?/;function pe(r,e,t,n,i,o){return Object.assign({},le,{name:i,parentNames:o,date:new Date,logLevelId:r,logLevelName:e,path:n?void 0:O(t)})}function O(r,e=Error()){var t,n,i;return j((i=(n=(t=e==null?void 0:e.stack)==null?void 0:t.split(`
`))==null?void 0:n.filter(o=>!o.includes("Error: ")))==null?void 0:i[r])}function v(r){var e,t,n;return(n=(t=((e=r==null?void 0:r.stack)==null?void 0:e.split(`
`))??[])==null?void 0:t.filter(i=>!i.includes("Error: ")))==null?void 0:n.reduce((i,o)=>(i.push(j(o)),i),[])}function j(r){var n;const e=(n=globalThis==null?void 0:globalThis.location)==null?void 0:n.origin,t={fullFilePath:void 0,fileName:void 0,fileNameWithLine:void 0,fileColumn:void 0,fileLine:void 0,filePath:void 0,filePathWithLine:void 0,method:void 0};if(r!=null){const i=r.match(ce);if(i){t.filePath=i[1].replace(/\?.*$/,""),t.fullFilePath=`${e}${t.filePath}`;const o=t.filePath.split("/");t.fileName=o[o.length-1],t.fileLine=i[2],t.fileColumn=i[3],t.filePathWithLine=`${t.filePath}:${t.fileLine}`,t.fileNameWithLine=`${t.fileName}:${t.fileLine}`}}return t}function M(r){return r instanceof Error}function ue(r,e){return r.reduce((t,n)=>(M(n)?t.errors.push(ee(n,e)):t.args.push(n),t),{args:[],errors:[]})}function ee(r,e){const t=v(r).map(i=>K(e,e.prettyErrorStackTemplate,{...i},!0)),n={errorName:` ${r.name} `,errorMessage:Object.getOwnPropertyNames(r).reduce((i,o)=>(o!=="stack"&&i.push(r[o]),i),[]).join(", "),errorStack:t.join(`
`)};return K(e,e.prettyErrorTemplate,n)}function me(r,e,t,n){const i=(t.length>0&&e.length>0?`
`:"")+t.join(`
`);n.prettyInspectOptions.colors=n.stylePrettyLogs,console.log(r+ae(n.prettyInspectOptions,...e)+i)}function de(r){console.log(g(r))}function ye(r){return!1}class we{constructor(e,t,n=4){var i,o,s,f,a,h,l,c;this.logObj=t,this.stackDepthLevel=n,this.runtime=he,this.settings={type:(e==null?void 0:e.type)??"pretty",name:e==null?void 0:e.name,parentNames:e==null?void 0:e.parentNames,minLevel:(e==null?void 0:e.minLevel)??0,argumentsArrayName:e==null?void 0:e.argumentsArrayName,hideLogPositionForProduction:(e==null?void 0:e.hideLogPositionForProduction)??!1,prettyLogTemplate:(e==null?void 0:e.prettyLogTemplate)??"{{yyyy}}.{{mm}}.{{dd}} {{hh}}:{{MM}}:{{ss}}:{{ms}}	{{logLevelName}}	{{filePathWithLine}}{{nameWithDelimiterPrefix}}	",prettyErrorTemplate:(e==null?void 0:e.prettyErrorTemplate)??`
{{errorName}} {{errorMessage}}
error stack:
{{errorStack}}`,prettyErrorStackTemplate:(e==null?void 0:e.prettyErrorStackTemplate)??`  • {{fileName}}	{{method}}
	{{filePathWithLine}}`,prettyErrorParentNamesSeparator:(e==null?void 0:e.prettyErrorParentNamesSeparator)??":",prettyErrorLoggerNameDelimiter:(e==null?void 0:e.prettyErrorLoggerNameDelimiter)??"	",stylePrettyLogs:(e==null?void 0:e.stylePrettyLogs)??!0,prettyLogTimeZone:(e==null?void 0:e.prettyLogTimeZone)??"UTC",prettyLogStyles:(e==null?void 0:e.prettyLogStyles)??{logLevelName:{"*":["bold","black","bgWhiteBright","dim"],SILLY:["bold","white"],TRACE:["bold","whiteBright"],DEBUG:["bold","green"],INFO:["bold","blue"],WARN:["bold","yellow"],ERROR:["bold","red"],FATAL:["bold","redBright"]},dateIsoStr:"white",filePathWithLine:"white",name:["white","bold"],nameWithDelimiterPrefix:["white","bold"],nameWithDelimiterSuffix:["white","bold"],errorName:["bold","bgRedBright","whiteBright"],fileName:["yellow"],fileNameWithLine:"white"},prettyInspectOptions:(e==null?void 0:e.prettyInspectOptions)??{colors:!0,compact:!1,depth:1/0},metaProperty:(e==null?void 0:e.metaProperty)??"_meta",maskPlaceholder:(e==null?void 0:e.maskPlaceholder)??"[***]",maskValuesOfKeys:(e==null?void 0:e.maskValuesOfKeys)??["password"],maskValuesOfKeysCaseInsensitive:(e==null?void 0:e.maskValuesOfKeysCaseInsensitive)??!1,maskValuesRegEx:e==null?void 0:e.maskValuesRegEx,prefix:[...(e==null?void 0:e.prefix)??[]],attachedTransports:[...(e==null?void 0:e.attachedTransports)??[]],overwrite:{mask:(i=e==null?void 0:e.overwrite)==null?void 0:i.mask,toLogObj:(o=e==null?void 0:e.overwrite)==null?void 0:o.toLogObj,addMeta:(s=e==null?void 0:e.overwrite)==null?void 0:s.addMeta,addPlaceholders:(f=e==null?void 0:e.overwrite)==null?void 0:f.addPlaceholders,formatMeta:(a=e==null?void 0:e.overwrite)==null?void 0:a.formatMeta,formatLogObj:(h=e==null?void 0:e.overwrite)==null?void 0:h.formatLogObj,transportFormatted:(l=e==null?void 0:e.overwrite)==null?void 0:l.transportFormatted,transportJSON:(c=e==null?void 0:e.overwrite)==null?void 0:c.transportJSON}}}log(e,t,...n){var c,y,w,S,L,P,N,E,k,A,C,T,B,F;if(e<this.settings.minLevel)return;const i=[...this.settings.prefix,...n],o=((c=this.settings.overwrite)==null?void 0:c.mask)!=null?(y=this.settings.overwrite)==null?void 0:y.mask(i):this.settings.maskValuesOfKeys!=null&&this.settings.maskValuesOfKeys.length>0?this._mask(i):i,s=this.logObj!=null?this._recursiveCloneAndExecuteFunctions(this.logObj):void 0,f=((w=this.settings.overwrite)==null?void 0:w.toLogObj)!=null?(S=this.settings.overwrite)==null?void 0:S.toLogObj(o,s):this._toLogObj(o,s),a=((L=this.settings.overwrite)==null?void 0:L.addMeta)!=null?(P=this.settings.overwrite)==null?void 0:P.addMeta(f,e,t):this._addMetaToLogObj(f,e,t);let h,l;return((N=this.settings.overwrite)==null?void 0:N.formatMeta)!=null&&(h=(E=this.settings.overwrite)==null?void 0:E.formatMeta(a==null?void 0:a[this.settings.metaProperty])),((k=this.settings.overwrite)==null?void 0:k.formatLogObj)!=null&&(l=(A=this.settings.overwrite)==null?void 0:A.formatLogObj(o,this.settings)),this.settings.type==="pretty"&&(h=h??this._prettyFormatLogObjMeta(a==null?void 0:a[this.settings.metaProperty]),l=l??this.runtime.prettyFormatLogObj(o,this.settings)),h!=null&&l!=null?((C=this.settings.overwrite)==null?void 0:C.transportFormatted)!=null?(T=this.settings.overwrite)==null||T.transportFormatted(h,l.args,l.errors,this.settings):this.runtime.transportFormatted(h,l.args,l.errors,this.settings):((B=this.settings.overwrite)==null?void 0:B.transportJSON)!=null?(F=this.settings.overwrite)==null||F.transportJSON(a):this.settings.type!=="hidden"&&this.runtime.transportJSON(a),this.settings.attachedTransports!=null&&this.settings.attachedTransports.length>0&&this.settings.attachedTransports.forEach(D=>{D(a)}),a}attachTransport(e){this.settings.attachedTransports.push(e)}getSubLogger(e,t){var o,s,f;const n={...this.settings,...e,parentNames:((o=this.settings)==null?void 0:o.parentNames)!=null&&((s=this.settings)==null?void 0:s.name)!=null?[...this.settings.parentNames,this.settings.name]:((f=this.settings)==null?void 0:f.name)!=null?[this.settings.name]:void 0,prefix:[...this.settings.prefix,...(e==null?void 0:e.prefix)??[]]};return new this.constructor(n,t??this.logObj,this.stackDepthLevel)}_mask(e){const t=this.settings.maskValuesOfKeysCaseInsensitive!==!0?this.settings.maskValuesOfKeys:this.settings.maskValuesOfKeys.map(n=>n.toLowerCase());return e==null?void 0:e.map(n=>this._recursiveCloneAndMaskValuesOfKeys(n,t))}_recursiveCloneAndMaskValuesOfKeys(e,t,n=[]){var i,o;if(n.includes(e))return{...e};if(typeof e=="object"&&e!==null&&n.push(e),this.runtime.isError(e)||this.runtime.isBuffer(e))return e;if(e instanceof Map)return new Map(e);if(e instanceof Set)return new Set(e);if(Array.isArray(e))return e.map(s=>this._recursiveCloneAndMaskValuesOfKeys(s,t,n));if(e instanceof Date)return new Date(e.getTime());if(e instanceof URL)return re(e);if(e!==null&&typeof e=="object"){const s=this.runtime.isError(e)?this._cloneError(e):Object.create(Object.getPrototypeOf(e));return Object.getOwnPropertyNames(e).reduce((f,a)=>{var h;return f[a]=t.includes(((h=this.settings)==null?void 0:h.maskValuesOfKeysCaseInsensitive)!==!0?a:a.toLowerCase())?this.settings.maskPlaceholder:(()=>{try{return this._recursiveCloneAndMaskValuesOfKeys(e[a],t,n)}catch{return null}})(),f},s)}else{if(typeof e=="string"){let s=e;for(const f of((i=this.settings)==null?void 0:i.maskValuesRegEx)||[])s=s.replace(f,((o=this.settings)==null?void 0:o.maskPlaceholder)||"");return s}return e}}_recursiveCloneAndExecuteFunctions(e,t=[]){return this.isObjectOrArray(e)&&t.includes(e)?this.shallowCopy(e):(this.isObjectOrArray(e)&&t.push(e),Array.isArray(e)?e.map(n=>this._recursiveCloneAndExecuteFunctions(n,t)):e instanceof Date?new Date(e.getTime()):this.isObject(e)?Object.getOwnPropertyNames(e).reduce((n,i)=>{const o=Object.getOwnPropertyDescriptor(e,i);if(o){Object.defineProperty(n,i,o);const s=e[i];n[i]=typeof s=="function"?s():this._recursiveCloneAndExecuteFunctions(s,t)}return n},Object.create(Object.getPrototypeOf(e))):e)}isObjectOrArray(e){return typeof e=="object"&&e!==null}isObject(e){return typeof e=="object"&&!Array.isArray(e)&&e!==null}shallowCopy(e){return Array.isArray(e)?[...e]:{...e}}_toLogObj(e,t={}){return e=e==null?void 0:e.map(n=>this.runtime.isError(n)?this._toErrorObject(n):n),this.settings.argumentsArrayName==null?e.length===1&&!Array.isArray(e[0])&&this.runtime.isBuffer(e[0])!==!0&&!(e[0]instanceof Date)?t=typeof e[0]=="object"&&e[0]!=null?{...e[0],...t}:{0:e[0],...t}:t={...t,...e}:t={...t,[this.settings.argumentsArrayName]:e},t}_cloneError(e){const t=new e.constructor;return Object.getOwnPropertyNames(e).forEach(n=>{t[n]=e[n]}),t}_toErrorObject(e){return{nativeError:e,name:e.name??"Error",message:e.message,stack:this.runtime.getErrorTrace(e)}}_addMetaToLogObj(e,t,n){return{...e,[this.settings.metaProperty]:this.runtime.getMeta(t,n,this.stackDepthLevel,this.settings.hideLogPositionForProduction,this.settings.name,this.settings.parentNames)}}_prettyFormatLogObjMeta(e){var s,f,a,h,l,c,y,w,S,L,P,N,E,k,A,C,T,B,F,D,x,J;if(e==null)return"";let t=this.settings.prettyLogTemplate;const n={};t.includes("{{yyyy}}.{{mm}}.{{dd}} {{hh}}:{{MM}}:{{ss}}:{{ms}}")?t=t.replace("{{yyyy}}.{{mm}}.{{dd}} {{hh}}:{{MM}}:{{ss}}:{{ms}}","{{dateIsoStr}}"):this.settings.prettyLogTimeZone==="UTC"?(n.yyyy=((s=e==null?void 0:e.date)==null?void 0:s.getUTCFullYear())??"----",n.mm=u((f=e==null?void 0:e.date)==null?void 0:f.getUTCMonth(),2,1),n.dd=u((a=e==null?void 0:e.date)==null?void 0:a.getUTCDate(),2),n.hh=u((h=e==null?void 0:e.date)==null?void 0:h.getUTCHours(),2),n.MM=u((l=e==null?void 0:e.date)==null?void 0:l.getUTCMinutes(),2),n.ss=u((c=e==null?void 0:e.date)==null?void 0:c.getUTCSeconds(),2),n.ms=u((y=e==null?void 0:e.date)==null?void 0:y.getUTCMilliseconds(),3)):(n.yyyy=((w=e==null?void 0:e.date)==null?void 0:w.getFullYear())??"----",n.mm=u((S=e==null?void 0:e.date)==null?void 0:S.getMonth(),2,1),n.dd=u((L=e==null?void 0:e.date)==null?void 0:L.getDate(),2),n.hh=u((P=e==null?void 0:e.date)==null?void 0:P.getHours(),2),n.MM=u((N=e==null?void 0:e.date)==null?void 0:N.getMinutes(),2),n.ss=u((E=e==null?void 0:e.date)==null?void 0:E.getSeconds(),2),n.ms=u((k=e==null?void 0:e.date)==null?void 0:k.getMilliseconds(),3));const i=this.settings.prettyLogTimeZone==="UTC"?e==null?void 0:e.date:new Date(((A=e==null?void 0:e.date)==null?void 0:A.getTime())-((C=e==null?void 0:e.date)==null?void 0:C.getTimezoneOffset())*6e4);n.rawIsoStr=i==null?void 0:i.toISOString(),n.dateIsoStr=i==null?void 0:i.toISOString().replace("T"," ").replace("Z",""),n.logLevelName=e==null?void 0:e.logLevelName,n.fileNameWithLine=((T=e==null?void 0:e.path)==null?void 0:T.fileNameWithLine)??"",n.filePathWithLine=((B=e==null?void 0:e.path)==null?void 0:B.filePathWithLine)??"",n.fullFilePath=((F=e==null?void 0:e.path)==null?void 0:F.fullFilePath)??"";let o=(D=this.settings.parentNames)==null?void 0:D.join(this.settings.prettyErrorParentNamesSeparator);return o=o!=null&&(e==null?void 0:e.name)!=null?o+this.settings.prettyErrorParentNamesSeparator:void 0,n.name=(e==null?void 0:e.name)!=null||o!=null?(o??"")+(e==null?void 0:e.name):"",n.nameWithDelimiterPrefix=n.name.length>0?this.settings.prettyErrorLoggerNameDelimiter+n.name:"",n.nameWithDelimiterSuffix=n.name.length>0?n.name+this.settings.prettyErrorLoggerNameDelimiter:"",((x=this.settings.overwrite)==null?void 0:x.addPlaceholders)!=null&&((J=this.settings.overwrite)==null||J.addPlaceholders(e,n)),K(this.settings,t,n)}}class Se extends we{constructor(e,t){const n=typeof window<"u"&&typeof document<"u",i=n?window.chrome!==void 0&&window.CSS!==void 0&&window.CSS.supports("color","green"):!1,o=n?/^((?!chrome|android).)*safari/i.test(navigator.userAgent):!1;e=e||{},e.stylePrettyLogs=e.stylePrettyLogs&&n&&!i?!1:e.stylePrettyLogs,super(e,t,o?4:5)}log(e,t,...n){return super.log(e,t,...n)}silly(...e){return super.log(0,"SILLY",...e)}trace(...e){return super.log(1,"TRACE",...e)}debug(...e){return super.log(2,"DEBUG",...e)}info(...e){return super.log(3,"INFO",...e)}warn(...e){return super.log(4,"WARN",...e)}error(...e){return super.log(5,"ERROR",...e)}fatal(...e){return super.log(6,"FATAL",...e)}getSubLogger(e,t){return super.getSubLogger(e,t)}}export{Se as L};
