import{a as b,g as P}from"../index.BYkIe1T0.js";var y={exports:{}};(function(S,E){(function(p,i){S.exports=i()})(b,function(){var p=function(){function i(n){return a.appendChild(n.dom),n}function f(n){for(var l=0;l<a.children.length;l++)a.children[l].style.display=l===n?"block":"none";c=n}var c=0,a=document.createElement("div");a.style.cssText="position:fixed;top:0;left:0;cursor:pointer;opacity:0.9;z-index:10000",a.addEventListener("click",function(n){n.preventDefault(),f(++c%a.children.length)},!1);var r=(performance||Date).now(),o=r,e=0,x=i(new p.Panel("FPS","#0ff","#002")),v=i(new p.Panel("MS","#0f0","#020"));if(self.performance&&self.performance.memory)var h=i(new p.Panel("MB","#f08","#201"));return f(0),{REVISION:16,dom:a,addPanel:i,showPanel:f,begin:function(){r=(performance||Date).now()},end:function(){e++;var n=(performance||Date).now();if(v.update(n-r,200),n>o+1e3&&(x.update(1e3*e/(n-o),100),o=n,e=0,h)){var l=performance.memory;h.update(l.usedJSHeapSize/1048576,l.jsHeapSizeLimit/1048576)}return n},update:function(){r=this.end()},domElement:a,setMode:f}};return p.Panel=function(i,f,c){var a=1/0,r=0,o=Math.round,e=o(window.devicePixelRatio||1),x=80*e,v=48*e,h=3*e,n=2*e,l=3*e,s=15*e,d=74*e,m=30*e,u=document.createElement("canvas");u.width=x,u.height=v,u.style.cssText="width:80px;height:48px";var t=u.getContext("2d");return t.font="bold "+9*e+"px Helvetica,Arial,sans-serif",t.textBaseline="top",t.fillStyle=c,t.fillRect(0,0,x,v),t.fillStyle=f,t.fillText(i,h,n),t.fillRect(l,s,d,m),t.fillStyle=c,t.globalAlpha=.9,t.fillRect(l,s,d,m),{dom:u,update:function(g,w){a=Math.min(a,g),r=Math.max(r,g),t.fillStyle=c,t.globalAlpha=1,t.fillRect(0,0,x,s),t.fillStyle=f,t.fillText(o(g)+" "+i+" ("+o(a)+"-"+o(r)+")",h,n),t.drawImage(u,l+e,s,d-e,m,l,s,d-e,m),t.fillRect(l+d-e,s,e,m),t.fillStyle=c,t.globalAlpha=.9,t.fillRect(l+d-e,s,e,o((1-g/w)*m))}}},p})})(y);var R=y.exports;const D=P(R);export{D as S};
