import"./vue.DgHH_kY-.js";var e=!1;function u(i,r,s){return Array.isArray(i)?(i.length=Math.max(i.length,r),i.splice(r,1,s),s):(i[r]=s,s)}function f(i,r){if(Array.isArray(i)){i.splice(r,1);return}delete i[r]}export{f as d,e as i,u as s};
